import Base from "../Base";
import Collection from "../Collection/Collection"
import DetailsRow from "comptechsoft-vue-foundation/src/~compvuetech/Classes/Datatable/DetailsRow";

class Datatable extends Base {

    constructor(name) {
        super()

        this.name = name
        this.id = name

        this.columns = new Collection()

        this.details_row = new DetailsRow()

        this.count = -1

        this.configurator = false
    }

    AddColumn(column) {
        this.count++;
        column.order_no = this.count;
        this.columns.Put(column.name, column)
        return this
    }

    AddDetailsRow(value) {
        this.details_row.component = value
        return this
    }

    get columnCount() {
        return this.columns.Count()
    }

    get columnsTotalWidth() {
        let width = 0, columns = this.columns.All()
        _.each(columns, col => {
            if(col.visible)
            {
                width += parseInt(col.width)
            }
        })
        return width
    }

    get columnsTotalPxWidth() {
        let width = 0, columns = this.columns.All()
        _.each(columns, col => {
            width += col.widthpx
        })
        return width
    }

    get detailsComponent() {
        return this.details_row.component
    }

    get detailedRecords() {
        return this.details_row.detailed
    }

    AddToDetailed(id) {
        this.details_row.AddToDetailed(id)
    }

    RemoveFromDetailed(id) {
        this.details_row.RemoveFromDetailed(id)
    }

    RowIsDetailed(id) {
        return this.details_row.Exists(id)
    }

    SaveConfigurator(columns) {
        let endpoint = document.head.querySelector('meta[name="base-url"]').content + '/user-preferences/save'
        axios.post(endpoint, {
            'code': 'datatable',
            'item': this.id,
            value: _.map(columns, col => {
                return {
                    name: col.name,
                    width: col.width,
                    visible: col.visible,
                    order_no: col.order_no,
                }
            })
        }).then(r => {
           this.configurator = false
        })
    }

    SetColumnWidths() {
        let endpoint = document.head.querySelector('meta[name="base-url"]').content + '/user-preferences/get'
        axios.post(endpoint, {
            'code': 'datatable',
            'item': this.id,
        }).then( r => {
            if(r.data.result)
            {
                _.each(this.columns.items, (column, key) => {
                    let config = _.find(r.data.result, item => item.name == key)
                    column.width = config.width
                    column.visible = config.visible
                    column.order_no = config.order_no                
                })
            }
        })
    }
}

export default Datatable